/*
   This file is part of TALER
   Copyright (C) 2022 Taler Systems SA

   TALER is free software; you can redistribute it and/or modify it under the
   terms of the GNU General Public License as published by the Free Software
   Foundation; either version 3, or (at your option) any later version.

   TALER is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
   A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along with
   TALER; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */
/**
 * @file pg_update_auditor_progress.h
 * @brief implementation of the update_auditor_progress function
 * @author Christian Grothoff
 */
#ifndef PG_UPDATE_GENERIC_SUPPRESSED_H
#define PG_UPDATE_GENERIC_SUPPRESSED_H

#include "taler/taler_util.h"
#include "taler/taler_json_lib.h"
#include "taler/taler_auditordb_plugin.h"


/**
   // FIXME: add comments
 * @return transaction status code
 */
enum GNUNET_DB_QueryStatus
TAH_PG_update_generic_suppressed (
  void *cls,
  enum TALER_AUDITORDB_DeletableSuppressableTables table,
  uint64_t row_id,
  bool suppressed);

#endif
